@@ -61,12 +61,21 @@ class Schedule(object):
             self.day = sched_yaml['day'].lower().capitalize()
             self.irc = sched_yaml['irc']
             self.freq = sched_yaml['frequency']
-            self.recurrence = supported_recurrences[sched_yaml['frequency']]
+            self._recurrence = sched_yaml['frequency']
         except KeyError as e:
             print("Invalid YAML meeting schedule definition - missing "
                   "attribute '{0}'".format(e.args[0]))
             raise
 
+        # Validate inputs
+        try:
+            self.recurrence = supported_recurrences[self._recurrence]
+        except KeyError as e:
+            print("Invalid meeting recurrence '{0}' - "
+                  "valid types: {1}".format(e.args[0],
+                                            supported_recurrences.keys()))
+            raise
+
         # optional: start_date defaults to the current date if not present
         if 'start_date' in sched_yaml:
             try:
@@ -74,7 +83,7 @@ class Schedule(object):
                     str(sched_yaml['start_date']), '%Y%m%d')
             except ValueError:
                 raise ValueError("Could not parse 'start_date' (%s) in %s" %
-                                (sched_yaml['start_date'], self.filefrom))
+                                 (sched_yaml['start_date'], self.filefrom))
         else:
             self.start_date = datetime.datetime.utcnow()
 
@@ -84,7 +93,7 @@ class Schedule(object):
                 self.duration = int(sched_yaml['duration'])
             except ValueError:
                 raise ValueError("Could not parse 'duration' (%s) in %s" %
-                                (sched_yaml['duration'], self.filefrom))
+                                 (sched_yaml['duration'], self.filefrom))
         else:
             self.duration = 60
 
