@@ -176,3 +176,99 @@ description: >
 agenda: |
   * Debate whether this should be a longer meeting
 """
+
+MEETING_WITH_START_DATE = """
+project: OpenStack Subteam 8 Meeting
+schedule:
+  - time: '1200'
+    duration: 30
+    day: Thursday
+    start_date: 20150801
+    irc: openstack-meeting
+    frequency: weekly
+chair: Shannon Stacker
+description: >
+    Weekly short meeting for Subteam project.
+agenda: |
+  * Debate whether this should be a longer meeting
+"""
+
+MEETING_WITH_SKIP_DATES = """
+project: OpenStack Subteam 8 Meeting
+schedule:
+  - time: '1200'
+    day: Monday
+    start_date: 20150801
+    irc: openstack-meeting
+    frequency: weekly
+    skip_dates:
+        - skip_date: 20150810
+          reason: Chair on vacation
+chair: Shannon Stacker
+description: >
+    Weekly short meeting for Subteam project.
+"""
+
+MEETING_WITH_SKIP_DATES_BAD_DATE = """
+project: OpenStack Subteam 8 Meeting
+schedule:
+  - time: '1200'
+    day: Monday
+    start_date: 20150801
+    irc: openstack-meeting
+    frequency: weekly
+    skip_dates:
+        - skip_date: 2015080
+          reason: Chair on vacation
+chair: Shannon Stacker
+description: >
+    Weekly short meeting for Subteam project.
+"""
+
+# typo in skip_date
+MEETING_WITH_MISSING_SKIP_DATE = """
+project: OpenStack Subteam 8 Meeting
+schedule:
+  - time: '1200'
+    day: Monday
+    start_date: 20150801
+    irc: openstack-meeting
+    frequency: weekly
+    skip_dates:
+        - skiip_date: 20150806
+          reason: Chair on vacation
+chair: Shannon Stacker
+description: >
+    Weekly short meeting for Subteam project.
+"""
+
+# typo in reason
+MEETING_WITH_MISSING_REASON = """
+project: OpenStack Subteam 8 Meeting
+schedule:
+  - time: '1200'
+    day: Monday
+    start_date: 20150801
+    irc: openstack-meeting
+    frequency: weekly
+    skip_dates:
+        - skip_date: 20150806
+          reaso: Chair on vacation
+chair: Shannon Stacker
+description: >
+    Weekly short meeting for Subteam project.
+"""
+
+# adhoc meeting
+ADHOC_MEETING = """
+project: OpenStack Random Meeting
+schedule:
+  - time: '1200'
+    day: Monday
+    start_date: 20150801
+    irc: openstack-meeting
+    frequency: adhoc
+chair: Shannon Stacker
+description: >
+    Adhoc random meeting for Subteam project.
+"""
